mangadap.proc package
=====================

Submodules
----------

.. toctree::
   :maxdepth: 4

   mangadap.proc.bandpassfilter
   mangadap.proc.elric
   mangadap.proc.emissionlinemodel
   mangadap.proc.emissionlinemoments
   mangadap.proc.emissionlinetemplates
   mangadap.proc.ppxffit
   mangadap.proc.reductionassessments
   mangadap.proc.rukia
   mangadap.proc.sasuke
   mangadap.proc.spatialbinning
   mangadap.proc.spatiallybinnedspectra
   mangadap.proc.spectralfitting
   mangadap.proc.spectralindices
   mangadap.proc.spectralstack
   mangadap.proc.stellarcontinuummodel
   mangadap.proc.templatelibrary
   mangadap.proc.util

Module contents
---------------

.. automodule:: mangadap.proc
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
